@@ -1,7 +1,7 @@
 from .add_json_answers_to_dictionary import add_json_answers_to_dictionary
 from .bronze_to_silver import bronze_to_silver
 from .constants import LABELBOX_DEFAULT_TYPE_DICTIONARY
-from .create_dataset import create_dataset
+from .create_labelbox_dataset import create_labelbox_dataset
 from .dataframe_schema_enrichment import dataframe_schema_enrichment
 from .flatten_bronze_table import flatten_bronze_table
 from .get_annotations import get_annotations
@@ -10,3 +10,4 @@ from .is_json import is_json
 from .jsonToDataFrame import jsonToDataFrame
 from .spark_schema_to_string import spark_schema_to_string
 from .dictionary_collector import dictionary_collector
+from .update_metadata import update_metadata
